@@ -42,7 +42,7 @@ class Collect(ElementValidationTask):
 
 
 class ExtractMarkers(SkippableMixin(), ElementValidationTask):
-    """Extract marker informations from the original morphology files, if any.
+    """Extract marker information from the original morphology files, if any.
 
     Markers are additional spatial information contained in some reconstructed morphologies.
     Some can be read by MorphIO (https://github.com/BlueBrain/MorphIO/pull/186).
@@ -166,10 +166,17 @@ class Sanitize(ElementValidationTask):
     here means that the soma does not have a valid type.
     """
 
+    ensure_roots_at_soma = luigi.BoolParameter(
+        default=True, description=":bool: Reconnect root sections at soma if they are not"
+    )
     output_columns = {"morph_path": None}
 
     validation_function = sanitize
 
+    def kwargs(self):
+        """ """
+        return {"ensure_roots_at_soma": self.ensure_roots_at_soma}
+
     def inputs(self):
         """ """
         return {CheckNeurites: {"morph_path": "morph_path"}}
@@ -246,7 +253,7 @@ class Align(SkippableMixin(True), ElementValidationTask):
     neurite_type = luigi.Parameter(
         default="apical", description=":str: Neurite to use to align morphology"
     )
-    direction = luigi.ListParameter(default=None)
+    direction = luigi.OptionalListParameter(default=None)
     custom_orientation_json_path = luigi.OptionalStrParameter(
         default=None, description=":str: Path to json with custom orientations"
     )
