@@ -31,7 +31,6 @@ class CollectAnnotated(ElementValidationTask):
         "cut_leaves_path": None,
         "apical_point_path": None,
     }
-    input_index_col = luigi.Parameter(default="morph_name")
 
     validation_function = collect
 
@@ -104,7 +103,7 @@ class RepairNeurites(ElementValidationTask):
     with_plot = BoolParameter(
         default=False, description=":bool: Save plots with highlighted repaired branches"
     )
-    repair_params = luigi.DictParameter(
+    repair_params = luigi.OptionalDictParameter(
         default=None, description=":dict: Repair internal parameters"
     )
 
@@ -157,16 +156,20 @@ class MakeCollage(SkippableMixin(), SetValidationTask):
 class MakeRelease(SetValidationTask):
     """Make a morpology release, with three possible folders: zero-diameter, unravel or repair."""
 
-    zero_diameter_path = luigi.Parameter(
+    zero_diameter_path = luigi.OptionalParameter(
         default=None, description=":str: Path to zero diameter morphologies (not created if None)"
     )
-    unravel_path = luigi.Parameter(
+    unravel_path = luigi.OptionalParameter(
         default=None, description=":str: Path to unravel morphologies (not created if None)"
     )
     repair_path = luigi.Parameter(
         default="repaired_release",
         description=":str: Path to repaired morphologies (not created if None)",
     )
+    duplicate_layers = luigi.BoolParameter(
+        default=True, description=":bool: Duplicate entries with mixed layer mtypes, i.e. L23_PC."
+    )
+
     extensions = [".asc", ".h5", ".swc"]
     output_columns = {}
     for extension in extensions:
@@ -179,6 +182,7 @@ class MakeRelease(SetValidationTask):
                 f"zero_diameter_release_morph_path_{ext}": None,
                 f"unravel_release_morph_path_{ext}": None,
                 f"repair_release_morph_path_{ext}": None,
+                "layer": None,
             }
         )
 
@@ -191,6 +195,7 @@ class MakeRelease(SetValidationTask):
             "unravel_path": self.unravel_path,
             "repair_path": self.repair_path,
             "extensions": self.extensions,
+            "duplicate_layers": self.duplicate_layers,
         }
 
     def inputs(self):
@@ -251,6 +256,6 @@ class PlotSmoothDiameters(SkippableMixin(True), ElementValidationTask):
     def inputs(self):
         """ """
         return {
-            RepairNeurites: {"morph_path": "morph_path"},
+            FixZeroDiameters: {"morph_path": "morph_path"},
             SmoothDiameters: {"morph_path": "smooth_morph_path"},
         }
